@@ -251,6 +251,38 @@ def human_delta(td_object: datetime.timedelta, max: int = 0):
     return sign + ", ".join(strings)  # + f"({td_object}, {ms})"
 
 
+
+def human_bytesize(bytes: int, max: int = 0):
+    if bytes == 0:
+        return "0 bytes"
+    if bytes < 0:
+        return "negative bytes (error)"
+    # fmt: off
+    KiB=1024
+    periods = [
+        ("PiB", KiB*KiB*KiB*KiB*KiB),
+        ("TiB", KiB*KiB*KiB*KiB),
+        ("GiB", KiB*KiB*KiB),
+        ("MiB", KiB*KiB),
+        ("KiB", KiB),
+        ("bytes", 1)
+    ]
+    # fmt: on
+
+    strings = []
+    ct: int = 0
+    for period_name, period_bytes in periods:
+        if bytes > period_bytes:
+            period_value, bytes = divmod(bytes, period_bytes)
+            # has_s = "s" if period_value > 1 else ""
+            # strings.append("%s %s%s" % (period_value, period_name, has_s))
+            strings.append(f"{period_value} {period_name}")
+            ct += 1
+            if max > 0 and ct > max:
+                break
+    return ", ".join(strings)  # + f"({td_object}, {bytes})"
+
+
 # Make washee conform strictly to structure of washer
 def wash_dict(washee, washer):
     out = {}
@@ -292,10 +324,12 @@ def read_file(fname, strip=True):
         logger.error(f"Could not find file {fn} relative to working directory {os.getcwd()}")
     return data
 
+
 def write_file(fn, data, strip=True):
     with open(fn, "w") as f:
         f.write(data.strip() if strip else data)
 
+
 def debug_imports():
     import logging
     import pprint
