@@ -9,7 +9,7 @@ logger = logging.getLogger(__name__)
 __version__ = "0.0.0"
 version_filename = "VERSION"
 
-fk_path: str = os.path.abspath(os.path.join(os.path.dirname(__file__), "../"))
+fk_path: str = os.path.abspath(os.path.join(os.path.dirname(__file__), "../../"))
 fk_version_file = f"{fk_path}/{version_filename}"
 
 if pkg_resources.resource_exists(__name__, version_filename):
